Learn R Programming

ratlas (version 0.1.1)

measr_pdf: Create an R Markdown PDF measr Report

Description

This is a function called in the output of the yaml of the Rmd file to specify using the standard measr report document formatting.

Usage

measr_pdf(...)

Value

A modified pdf_document2 with the standard tech report formatting.

Arguments

...

Arguments to be passed to [bookdown::pdf_document2]

Examples

Run this code
if (FALSE) {
output: ratlas::measr_pdf
}

Run the code above in your browser using DataLab