Learn R Programming

ratlas (version 0.1.1)

palette_lcrost: Color palette proposed by Lisa Charlotte Rost

Description

A colorblind friendly palette taken from the article What to consider when visualizing data for colorblind readers

Usage

palette_lcrost

palette_lcrost_black

Arguments

Format

An object of class character of length 8.

An object of class character of length 8.