powered by
This is a function called in the output of the yaml of the Rmd file to specify using the standard measr report document formatting.
measr_pdf(...)
A modified pdf_document2 with the standard tech report formatting.
pdf_document2
Arguments to be passed to [bookdown::pdf_document2]
[bookdown::pdf_document2]
if (FALSE) { output: ratlas::measr_pdf }
Run the code above in your browser using DataLab