if (FALSE) {
library(ggplot2)
library(dplyr)
# seminal scatterplot
ggplot(mtcars, aes(mpg, wt)) +
geom_point() +
labs(x = "Fuel effiiency (mpg)", y = "Weight (tons)",
title = "Seminal ggplot2 scatterplot example",
subtitle = "A plot that is only useful for demonstration purposes",
caption = "Brought to you by the letter 'g'") +
theme_atlas()
# seminal bar chart
update_geom_font_defaults()
count(mpg, class) %>%
ggplot(aes(class, n)) +
geom_col() +
geom_text(aes(label=n), nudge_y=3) +
labs(x = "Fuel efficiency (mpg)", y = "Weight (tons)",
title = "Seminal ggplot2 bar chart example",
subtitle = "A plot that is only useful for demonstration purposes",
caption = "Brought to you by the letter 'g'") +
theme_atlas(grid = "Y") +
theme(axis.text.y = element_blank())
}
Run the code above in your browser using DataLab